Package: CatastRo
Title: Interface to the API 'Sede Electronica Del Catastro'
Version: 0.4.1
Authors@R: c(
    person("Ángel", "Delgado Panadero", , "delgadopanadero@gmail.com", role = c("aut", "cph"),
           comment = c(ORCID = "0000-0002-8189-9251")),
    person("Iñaki", "Ucar", role = "ctb",
           comment = c(ORCID = "0000-0001-6403-5550")),
    person("Diego", "Hernangómez", , "diego.hernangomezherrero@gmail.com", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0001-8457-4658"))
  )
Description: Access public spatial data available under the 'INSPIRE'
    directive. Tools for downloading references and addresses of
    properties, as well as map images.
License: GPL-2
URL: https://ropenspain.github.io/CatastRo/,
        https://github.com/rOpenSpain/CatastRo
BugReports: https://github.com/rOpenSpain/CatastRo/issues
Depends: R (>= 3.6)
Imports: dplyr, httr2 (>= 1.0.0), mapSpain (>= 0.7.0), rappdirs (>=
        0.3.0), sf (>= 1.0.0), stringi, terra, tibble, xml2
Suggests: ggplot2, knitr, png, rmarkdown, slippymath, testthat (>=
        3.0.0), tidyterra
VignetteBuilder: knitr
Config/Needs/website: ropenspain/rostemplate, devtools, sessioninfo,
        remotes, sfheaders, rapidjsonr, jsonify, geometries
Config/testthat/edition: 3
Config/testthat/parallel: true
Copyright: © Dirección General del Catastro
        <https://www.catastro.meh.es/>
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.2
X-schema.org-isPartOf: https://ropenspain.es/
X-schema.org-keywords: catastro, cran, cran-r, gis, maps, r, r-package,
        ropenspain, rstats, spain, spatial, static-tiles
NeedsCompilation: no
Packaged: 2025-03-24 21:17:49 UTC; diego
Author: Ángel Delgado Panadero [aut, cph]
    (<https://orcid.org/0000-0002-8189-9251>),
  Iñaki Ucar [ctb] (<https://orcid.org/0000-0001-6403-5550>),
  Diego Hernangómez [aut, cre] (<https://orcid.org/0000-0001-8457-4658>)
Maintainer: Diego Hernangómez <diego.hernangomezherrero@gmail.com>
Repository: CRAN
Date/Publication: 2025-03-24 21:30:01 UTC
Built: R 4.3.3; ; 2025-03-25 00:20:41 UTC; unix
