# Generated by roxygen2: do not edit by hand

export(catr_atom_get_address)
export(catr_atom_get_address_db_all)
export(catr_atom_get_address_db_to)
export(catr_atom_get_buildings)
export(catr_atom_get_buildings_db_all)
export(catr_atom_get_buildings_db_to)
export(catr_atom_get_parcels)
export(catr_atom_get_parcels_db_all)
export(catr_atom_get_parcels_db_to)
export(catr_atom_search_munic)
export(catr_clear_cache)
export(catr_detect_cache_dir)
export(catr_get_code_from_coords)
export(catr_ovc_get_cod_munic)
export(catr_ovc_get_cod_provinces)
export(catr_ovc_get_cpmrc)
export(catr_ovc_get_rccoor)
export(catr_ovc_get_rccoor_distancia)
export(catr_set_cache_dir)
export(catr_wfs_get_address_bbox)
export(catr_wfs_get_address_codvia)
export(catr_wfs_get_address_postalcode)
export(catr_wfs_get_address_rc)
export(catr_wfs_get_buildings_bbox)
export(catr_wfs_get_buildings_rc)
export(catr_wfs_get_parcels_bbox)
export(catr_wfs_get_parcels_neigh_parcel)
export(catr_wfs_get_parcels_parcel)
export(catr_wfs_get_parcels_parcel_zoning)
export(catr_wfs_get_parcels_zoning)
export(catr_wms_get_layer)
export(inspire_wfs_get)
export(run_example)
importFrom(lifecycle,deprecated)
importFrom(utils,URLencode)
importFrom(utils,adist)
importFrom(utils,modifyList)
importFrom(utils,object.size)
importFrom(utils,unzip)
