list(
  rd_family_title = list(
    ATOM = "Other INSPIRE ATOM services:",
    WFS = "Other INSPIRE WFS services:",
    WMS = "Other INSPIRE WMS services:",
    INSPIRE = "INSPIRE API functions:",
    OVCCoordenadas = "OVCCoordenadas API:",
    OVCCallejero = "OVCCoordenadas API:"
  )
)
