# get_sf_from_bbox

    Code
      get_sf_from_bbox(c(1, 2))
    Condition
      Error in `get_sf_from_bbox()`:
      ! `bbox` has length 4, not 2.

---

    Code
      get_sf_from_bbox(c(1, 2, 1, 2))
    Condition
      Error in `get_sf_from_bbox()`:
      ! Please provide a valid non-empty value for `srs`.

