# Mock migration

    Code
      detected <- detect_cache_dir_muted()
    Message
      v CatastRo >= 1.0.0: Cache configuration migrated. See Note in `CatastRo::catr_set_cache_dir()` for details.
      i This is a one-time message, it won't be displayed in the future.

