% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/CatastRo-package.R
\docType{package}
\name{CatastRo-package}
\alias{CatastRo}
\alias{CatastRo-package}
\title{CatastRo: Interface to the API 'Sede Electronica Del Catastro'}
\description{
\if{html}{\figure{logo.png}{options: style='float: right' alt='logo' width='120'}}

Access public spatial data available under the 'INSPIRE' directive. Tools for downloading references and addresses of properties, as well as map images.
}
\seealso{
Useful links:
\itemize{
  \item \url{https://ropenspain.github.io/CatastRo/}
  \item \url{https://github.com/rOpenSpain/CatastRo}
  \item Report bugs at \url{https://github.com/rOpenSpain/CatastRo/issues}
}

}
\author{
\strong{Maintainer}: Diego Hernangómez \email{diego.hernangomezherrero@gmail.com} (\href{https://orcid.org/0000-0001-8457-4658}{ORCID})

Authors:
\itemize{
  \item Diego Hernangómez \email{diego.hernangomezherrero@gmail.com} (\href{https://orcid.org/0000-0001-8457-4658}{ORCID})
  \item Ángel Delgado Panadero \email{delgadopanadero@gmail.com} (\href{https://orcid.org/0000-0002-8189-9251}{ORCID}) [copyright holder]
}

Other contributors:
\itemize{
  \item Iñaki Ucar (\href{https://orcid.org/0000-0001-6403-5550}{ORCID}) [contributor]
}

}
\keyword{internal}
