% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ovc-provinces.R
\encoding{UTF-8}
\name{catr_ovc_get_cod_provinces}
\alias{catr_ovc_get_cod_provinces}
\title{OVCCallejero: Extract a list of provinces with their codes}
\usage{
catr_ovc_get_cod_provinces(verbose = FALSE)
}
\arguments{
\item{verbose}{Logical. If \code{TRUE}, displays informational messages.}
}
\value{
A \link[tibble:tbl_df]{tibble}.
}
\description{
Implementation of the OVCCallejero service
\href{https://ovc.catastro.meh.es/ovcservweb/ovcswlocalizacionrc/ovccallejerocodigos.asmx?op=ConsultaProvincia}{ConsultaProvincia}. Returns a list of provinces
included in the Spanish Cadastre.
}
\examples{
\dontshow{if (run_example()) withAutoprint(\{ # examplesIf}
\donttest{
catr_ovc_get_cod_provinces()
}
\dontshow{\}) # examplesIf}
}
\references{
\href{https://ovc.catastro.meh.es/ovcservweb/ovcswlocalizacionrc/ovccallejerocodigos.asmx?op=ConsultaProvincia}{ConsultaProvincia}.
}
\seealso{
OVCCoordenadas API:
\code{\link[=catr_ovc_get_cod_munic]{catr_ovc_get_cod_munic()}}

Other search:
\code{\link[=catr_atom_search_munic]{catr_atom_search_munic()}},
\code{\link[=catr_get_code_from_coords]{catr_get_code_from_coords()}},
\code{\link[=catr_ovc_get_cod_munic]{catr_ovc_get_cod_munic()}}
}
\concept{OVCCallejero}
\concept{search}
