% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils-wfs.R
\encoding{UTF-8}
\name{inspire_wfs_get}
\alias{inspire_wfs_get}
\title{Client tool for WFS INSPIRE services}
\usage{
inspire_wfs_get(
  scheme = "https",
  hostname = "ovc.catastro.meh.es",
  path = "INSPIRE/wfsCP.aspx",
  query = list(),
  verbose = FALSE
)
}
\arguments{
\item{scheme}{Character string. Protocol to access the resource on the
Internet.}

\item{hostname}{Character string. Host that holds the resource.}

\item{path}{Character string. Specific resource in the host to access.}

\item{query}{Named list. Names and values of arguments to query.}

\item{verbose}{Logical. If \code{TRUE}, displays informational messages.}
}
\value{
Character string. Path of the resulting file in the \code{\link[=tempfile]{tempfile()}} folder.
}
\description{
Access WFS INSPIRE services. This function is used internally in WFS calls
and is exposed for users and developers accessing other cadastral or
INSPIRE resources.
}
\details{
This function is used internally in all the WFS calls. We expose it to make
it available to other users and/or developers for accessing other
cadastral or INSPIRE resources. See \strong{Examples}.
}
\examples{
\dontshow{if (run_example()) withAutoprint(\{ # examplesIf}
# Accessing the Cadastre of Navarra
# Try also https://ropenspain.github.io/CatastRoNav/

file_local <- inspire_wfs_get(
  hostname = "inspire.navarra.es",
  path = "services/BU/wfs",
  query = list(
    service = "WFS",
    request = "getfeature",
    typenames = "BU:Building",
    bbox = "609800,4740100,611000,4741300",
    SRSNAME = "EPSG:25830"
  )
)

if (!is.null(file_local)) {
  pamp <- sf::read_sf(file_local)

  library(ggplot2)
  ggplot(pamp) +
    geom_sf()
}
\dontshow{\}) # examplesIf}
}
\seealso{
INSPIRE API functions:
\code{\link[=catr_atom_get_address]{catr_atom_get_address()}},
\code{\link[=catr_atom_get_address_db_all]{catr_atom_get_address_db_all()}},
\code{\link[=catr_atom_get_buildings]{catr_atom_get_buildings()}},
\code{\link[=catr_atom_get_buildings_db_all]{catr_atom_get_buildings_db_all()}},
\code{\link[=catr_atom_get_parcels]{catr_atom_get_parcels()}},
\code{\link[=catr_atom_get_parcels_db_all]{catr_atom_get_parcels_db_all()}},
\code{\link[=catr_wfs_get_address_bbox]{catr_wfs_get_address_bbox()}},
\code{\link[=catr_wfs_get_buildings_bbox]{catr_wfs_get_buildings_bbox()}},
\code{\link[=catr_wfs_get_parcels_bbox]{catr_wfs_get_parcels_bbox()}},
\code{\link[=catr_wms_get_layer]{catr_wms_get_layer()}}

Other INSPIRE WFS services:
\code{\link{catr_srs_values}},
\code{\link[=catr_wfs_get_address_bbox]{catr_wfs_get_address_bbox()}},
\code{\link[=catr_wfs_get_buildings_bbox]{catr_wfs_get_buildings_bbox()}},
\code{\link[=catr_wfs_get_parcels_bbox]{catr_wfs_get_parcels_bbox()}}
}
\concept{INSPIRE}
\concept{WFS}
