% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/run-example.R
\encoding{UTF-8}
\name{run_example}
\alias{run_example}
\title{Decide whether an example should run}
\usage{
run_example()
}
\value{
Logical. \code{TRUE} if examples should run, \code{FALSE} otherwise.
}
\description{
Determine whether an example should run based on the current platform and
network availability.
}
\details{
Returns \code{FALSE} on CRAN, macOS, or when offline.
}
\examples{
run_example()

}
\keyword{internal}
